# Simgle
Helps you save time and money by easily finding the cheapest virtual numbers on [OnlineSim](https://onlinesim.io).

## Installation
> [!IMPORTANT]
> Make sure you have Python 3.9+ installed.

Install the utility from PyPI:
```sh
pip install simgle
```

## Usage
After installing, you can use it like this:
```sh
simgle [arguments]
```

> [!TIP]
> To see all available flags and arguments, run:
> ```sh
> simgle --help
> ```
> This will display a list of all the options and how to use them.

### Example
![Usage showcase](https://raw.githubusercontent.com/zelevar/simgle/b5076c591e897e175c393a42d0e7491650ad87eb/images/showcase.png)
